@@ -38,6 +38,9 @@ class Section(namedtuple("SectionBase", "title key type")):
 
 
 GOOGLE_TYPED_ARG_REGEX = re.compile(r"\s*(.+?)\s*\(\s*(.*[^\s]+)\s*\)")
+GOOGLE_ARG_DESC_REGEX = re.compile(r".*\. Defaults to (.+)\.")
+MULTIPLE_PATTERN = re.compile(r"(\s*[^:\s]+:)|([^:]*\]:.*)")
+
 DEFAULT_SECTIONS = [
     Section("Arguments", "param", SectionType.MULTIPLE),
     Section("Args", "param", SectionType.MULTIPLE),
@@ -95,7 +98,7 @@ class GoogleParser:
 
         if (
             section.type == SectionType.SINGULAR_OR_MULTIPLE
-            and ":" not in text.split()[0]
+            and not MULTIPLE_PATTERN.match(text)
         ) or section.type == SectionType.SINGULAR:
             return self._build_single_meta(section, text)
 
@@ -144,12 +147,17 @@ class GoogleParser:
             else:
                 arg_name, type_name = before, None
                 is_optional = None
+
+            m = GOOGLE_ARG_DESC_REGEX.match(desc)
+            default = m.group(1) if m else None
+
             return DocstringParam(
                 args=[section.key, before],
                 description=desc,
                 arg_name=arg_name,
                 type_name=type_name,
                 is_optional=is_optional,
+                default=default,
             )
         if section.key in RETURNS_KEYWORDS | YIELDS_KEYWORDS:
             return DocstringReturns(
